==> zio-aws-computeoptimizer_2.13-5.17.147.1-sources.jar: zio/aws/computeoptimizer/model/GetAutoScalingGroupRecommendationsRequest.scala <==
package zio.aws.computeoptimizer.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.computeoptimizer.model.primitives.{
  MaxResults,
  NextToken,
  AutoScalingGroupArn,
  AccountId
}
import scala.jdk.CollectionConverters._
final case class GetAutoScalingGroupRecommendationsRequest(
    accountIds: Option[Iterable[AccountId]] = None,
    autoScalingGroupArns: Option[Iterable[AutoScalingGroupArn]] = None,
    nextToken: Option[NextToken] = None,
    maxResults: Option[MaxResults] = None,
    filters: Option[Iterable[zio.aws.computeoptimizer.model.Filter]] = None,
    recommendationPreferences: Option[
      zio.aws.computeoptimizer.model.RecommendationPreferences
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest = {
    import GetAutoScalingGroupRecommendationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
      .builder()
      .optionallyWith(
        accountIds.map(value =>
          value.map { item =>
            AccountId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.accountIds)
      .optionallyWith(
        autoScalingGroupArns.map(value =>
          value.map { item =>
            AutoScalingGroupArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.autoScalingGroupArns)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        recommendationPreferences.map(value => value.buildAwsValue())
      )(_.recommendationPreferences)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest.ReadOnly =
    zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
      .wrap(buildAwsValue())
}
object GetAutoScalingGroupRecommendationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest =
      zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest(
        accountIds.map(value => value),
        autoScalingGroupArns.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        recommendationPreferences.map(value => value.asEditable)
      )
    def accountIds: Option[List[AccountId]]
    def autoScalingGroupArns: Option[List[AutoScalingGroupArn]]
    def nextToken: Option[NextToken]
    def maxResults: Option[MaxResults]
    def filters: Option[List[zio.aws.computeoptimizer.model.Filter.ReadOnly]]
    def recommendationPreferences: Option[
      zio.aws.computeoptimizer.model.RecommendationPreferences.ReadOnly
    ]
    def getAccountIds: ZIO[Any, AwsError, List[AccountId]] =
      AwsError.unwrapOptionField("accountIds", accountIds)
    def getAutoScalingGroupArns: ZIO[Any, AwsError, List[AutoScalingGroupArn]] =
      AwsError.unwrapOptionField("autoScalingGroupArns", autoScalingGroupArns)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.Filter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getRecommendationPreferences: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.RecommendationPreferences.ReadOnly
    ] = AwsError.unwrapOptionField(
      "recommendationPreferences",
      recommendationPreferences
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
  ) extends zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest.ReadOnly {
    override val accountIds: Option[List[AccountId]] = scala
      .Option(impl.accountIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.AccountId(item)
        }.toList
      )
    override val autoScalingGroupArns: Option[List[AutoScalingGroupArn]] = scala
      .Option(impl.autoScalingGroupArns())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.AutoScalingGroupArn(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.computeoptimizer.model.primitives.MaxResults(value))
    override val filters
        : Option[List[zio.aws.computeoptimizer.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.Filter.wrap(item)
        }.toList
      )
    override val recommendationPreferences: Option[
      zio.aws.computeoptimizer.model.RecommendationPreferences.ReadOnly
    ] = scala
      .Option(impl.recommendationPreferences())
      .map(value =>
        zio.aws.computeoptimizer.model.RecommendationPreferences.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
  ): zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_2.13-5.17.181.1-sources.jar: zio/aws/computeoptimizer/model/GetAutoScalingGroupRecommendationsRequest.scala <==
package zio.aws.computeoptimizer.model
import zio.aws.computeoptimizer.model.primitives.{
  MaxResults,
  NextToken,
  AutoScalingGroupArn,
  AccountId
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetAutoScalingGroupRecommendationsRequest(
    accountIds: Optional[Iterable[AccountId]] = Optional.Absent,
    autoScalingGroupArns: Optional[Iterable[AutoScalingGroupArn]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.computeoptimizer.model.Filter]] =
      Optional.Absent,
    recommendationPreferences: Optional[
      zio.aws.computeoptimizer.model.RecommendationPreferences
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest = {
    import GetAutoScalingGroupRecommendationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
      .builder()
      .optionallyWith(
        accountIds.map(value =>
          value.map { item =>
            AccountId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.accountIds)
      .optionallyWith(
        autoScalingGroupArns.map(value =>
          value.map { item =>
            AutoScalingGroupArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.autoScalingGroupArns)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        recommendationPreferences.map(value => value.buildAwsValue())
      )(_.recommendationPreferences)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest.ReadOnly =
    zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
      .wrap(buildAwsValue())
}
object GetAutoScalingGroupRecommendationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest =
      zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest(
        accountIds.map(value => value),
        autoScalingGroupArns.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        recommendationPreferences.map(value => value.asEditable)
      )
    def accountIds: Optional[List[AccountId]]
    def autoScalingGroupArns: Optional[List[AutoScalingGroupArn]]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def filters: Optional[List[zio.aws.computeoptimizer.model.Filter.ReadOnly]]
    def recommendationPreferences: Optional[
      zio.aws.computeoptimizer.model.RecommendationPreferences.ReadOnly
    ]
    def getAccountIds: ZIO[Any, AwsError, List[AccountId]] =
      AwsError.unwrapOptionField("accountIds", accountIds)
    def getAutoScalingGroupArns: ZIO[Any, AwsError, List[AutoScalingGroupArn]] =
      AwsError.unwrapOptionField("autoScalingGroupArns", autoScalingGroupArns)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.Filter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getRecommendationPreferences: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.RecommendationPreferences.ReadOnly
    ] = AwsError.unwrapOptionField(
      "recommendationPreferences",
      recommendationPreferences
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
  ) extends zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest.ReadOnly {
    override val accountIds: Optional[List[AccountId]] = zio.aws.core.internal
      .optionalFromNullable(impl.accountIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.AccountId(item)
        }.toList
      )
    override val autoScalingGroupArns: Optional[List[AutoScalingGroupArn]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.autoScalingGroupArns())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.computeoptimizer.model.primitives.AutoScalingGroupArn(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.computeoptimizer.model.primitives.MaxResults(value))
    override val filters
        : Optional[List[zio.aws.computeoptimizer.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.computeoptimizer.model.Filter.wrap(item)
          }.toList
        )
    override val recommendationPreferences: Optional[
      zio.aws.computeoptimizer.model.RecommendationPreferences.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.recommendationPreferences())
      .map(value =>
        zio.aws.computeoptimizer.model.RecommendationPreferences.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest
  ): zio.aws.computeoptimizer.model.GetAutoScalingGroupRecommendationsRequest.ReadOnly =
    new Wrapper(impl)
}
